@@ -6,7 +6,7 @@
 # @Author       : betterme
 # @WeChat       : meutils
 # @Software     : PyCharm
-# @Description  : 统一收口
+# @Description  : 统一收口 todo 硅基
 import os
 
 from meutils.pipe import *
@@ -78,7 +78,7 @@ async def generate(
         request = RecraftImageRequest(**request.model_dump(exclude_none=True))
         return await recraft_generate(request)
 
-    if request.model.startswith(("seed", "seededit_v3.0", "byteedit_v2.0", "i2i_portrait_photo")):  # seededit seedream
+    if request.model.startswith(("jimeng", "seed", "seededit_v3.0", "byteedit_v2.0", "i2i_portrait_photo")):  # seededit seedream
         return await volc_generate(request, api_key)
 
     if request.model.startswith(("jimeng")):  # 即梦
