@@ -15,12 +15,7 @@ from meutils.decorators.retry import retrying
 from meutils.str_utils.regular_expression import has_chinese
 
 from meutils.apis import niutrans
-from meutils.llm.clients import AsyncOpenAI  # zhipuai_client
-
-zhipuai_client = AsyncOpenAI(
-    api_key=os.getenv("ZHIPUAI_API_KEY"),
-    base_url="https://all.chatfire.cn/zhipu/v1"
-)
+from meutils.llm.clients import AsyncOpenAI, zhipuai_client  # zhipuai_client
 
 
 @alru_cache
