@@ -41,7 +41,7 @@ async def generate(request: ImageRequest, token: Optional[str] = None):
         "req_key": "high_aes_general_v30l_zt2i",
         # "req_key": "jimeng_high_aes_general_v21_L",
 
-        "seed": request.seed,
+        "seed": request.seed or -1,
         "width": 1328,
         "height": 1328,
         "return_url": request.response_format == "url",  # 24小时
@@ -51,9 +51,12 @@ async def generate(request: ImageRequest, token: Optional[str] = None):
         # "use_rephraser": True
     }
 
+    if request.model == "jimeng_t2i_v31":
+        payload["req_key"] = request.model  # 模型名称 重定向
+
     if request.image_urls:
         payload["image_urls"] = request.image_urls
-        payload["req_key"] = request.model
+
         if payload["req_key"] not in {"seededit_v3.0", "byteedit_v2.0"}:
             payload["req_key"] = "byteedit_v2.0"  # "seededit_v3.0" https://www.volcengine.com/docs/85128/1602254
 
@@ -62,6 +65,8 @@ async def generate(request: ImageRequest, token: Optional[str] = None):
     payload['height'] = height
     payload['prompt'] = request.prompt
 
+    logger.debug(bjson(payload))
+
     if request.response_format == "oss_url":
         payload["return_url"] = False
     try:
@@ -69,11 +74,7 @@ async def generate(request: ImageRequest, token: Optional[str] = None):
         logger.debug(bjson(response))
     except Exception as exc:  #
         logger.error(exc)
-        from fastapi import HTTPException, status
-        raise HTTPException(
-            status_code=status.HTTP_400_BAD_REQUEST,
-            detail=f"Prompt is sensitive.\n\n{request.prompt}\n\n{exc}",
-        )
+        raise exc
 
     if request.response_format == "b64_json":
         data = [{"b64_json": b64_json} for b64_json in response['data'].get('binary_data_base64', [])]
@@ -103,17 +104,19 @@ if __name__ == '__main__':
     
     让这个女人带上眼镜 衣服换个颜色
     """
-    prompt = "裸体女孩"
+    # prompt = "裸体女孩"
 
     request = ImageRequest(
         # model="high_aes_general_v30l_zt2i",
-        model="seededit_v3.0",
+        # model="seededit_v3.0",
+        model="jimeng_t2i_v31",
         prompt=prompt,
         response_format="url",
-        size="512x1328",
+        seed=-1,
+        # size="512x1328",
         # image="https://oss.ffire.cc/files/kling_watermark.png"
     )
-
+    print(request.size)
     arun(generate(request, token=token))
 
     # with timer():
