@@ -27,7 +27,14 @@ from meutils.schemas.openai_types import chat_completion, chat_completion_chunk,
 
 from meutils.schemas.image_types import ImageRequest, ImageEditRequest
 
-token_encoder = tiktoken.get_encoding('cl100k_base') # o200k_base
+# ['gpt2',
+#  'r50k_base',
+#  'p50k_base',
+#  'p50k_edit',
+#  'cl100k_base',
+#  'o200k_base',
+#  'o200k_harmony']
+token_encoder = tiktoken.get_encoding('o200k_base') # o200k_base
 token_encoder_with_cache = lru_cache(maxsize=1024)(token_encoder.encode)
 
 CHAT_COMPLETION_PARAMS = get_function_params()
