@@ -191,8 +191,11 @@ MODEL_PRICE = {
     "gemini-2.5-flash-video": 0.05,
     "gemini-2.5-pro-video": 0.1,
 
+    "qwen3-vl-plus-video": 0.1,
+    "qwen3-vl-plus-video-thinking": 0.1,
+
     # rix
-    "kling_image": 0.025,
+    "kling_image": 0.035,
     "kling_image_expand": 0.3,
     "kling_virtual_try_on": 1,
     "kling_effects": 1,
@@ -220,6 +223,7 @@ MODEL_PRICE = {
     "doubao-seedream-4-0-250828": 0.1,
     "doubao-seedream-3-0-t2i-250415": 0.05,
     "doubao-seededit-3-0-i2i-250628": 0.05,
+    "jimeng_t2i_v31": 0.05,
 
     "doubao-seedance-1-0-pro": 0.5,  # 480 1080
     "doubao-seedance-1-0-pro-250528": 0.5,  # 480 1080
@@ -266,6 +270,8 @@ MODEL_PRICE = {
 
     "sora-1:1-480p-5s": 1.2,
     "dall-e-3": 0.03,
+    "sora-2": 0.2,
+    "sora-2-hd": 0.2,
 
     # rag
     "qwen3-reranker-0.6b": 0.0011,
@@ -329,6 +335,7 @@ MODEL_PRICE = {
     "flux-pro-1.1-ultra": 0.2,
     "ideogram-ai/ideogram-v2": 0.2,
     "ideogram-ai/ideogram-v2-turbo": 0.1,
+    "ideogram-v3": 0.06 * 3,
 
     "imagen3": 0.05 * 3,
     "imagen3-fast": 0.025 * 3,
@@ -441,7 +448,7 @@ MODEL_PRICE = {
     "api-textin-crop_enhance_image": 0.03,
 
     # suno
-    "suno_music": 0.4,
+    "suno_music": 0.45,
     "suno_lyrics": 0.01,
     "suno_uploads": 0.01,
     "suno_upload": 0.01,
@@ -611,12 +618,12 @@ MODEL_RATIO = {
     "fal-minimax-speech-02-hd": 3 * 0.1 * 1000 / 2,
     "fal-minimax-speech-02-turbo": 3 * 0.06 * 1000 / 2,
 
+    "fal-wan-v2.2-14b-animate-move": 3 * 0.06 * 1000 / 2,
+    "fal-wan-v2.2-14b-animate-replace": 3 * 0.06 * 1000 / 2,
+
     "minimax-speech-02-hd": 125,
     "minimax-speech-02-turbo": 75,
 
-    "fal-ai/minimax/speech-02-hd": 3 * 0.1 * 1000 / 2,
-    "fal-ai/minimax/speech-02-turbo": 3 * 0.06 * 1000 / 2,
-
     # 智能体
     "gpt-4-plus": 2.5,
     "gpt-4o-plus": 2.5,
@@ -748,6 +755,10 @@ MODEL_RATIO = {
     "glm-4.5": 2,
     "glm-4.5-x": 6,
     "glm-4.5v": 1,
+    "glm-4.6": 2,
+
+    "longcat-flash-chat": 1,
+    "longcat-flash-thinking": 2,
 
     # 阿里千问 https://dashscope.console.aliyun.com/billing
     "qwen-long": 0.25,
@@ -803,6 +814,7 @@ MODEL_RATIO = {
 
     "qwen3-coder-plus": 2,
     "qwen3-coder-plus-2025-07-22": 2,
+    "qwen3-coder-plus-2025-09-23": 2,
 
     "qwq-32b": 0.5,
     "qwq-plus": 0.8,
@@ -894,6 +906,8 @@ MODEL_RATIO = {
 
     "deepseek-v3-1-terminus": 2,
     "deepseek-v3.1-terminus": 2,
+    "deepseek-v3.2-exp": 1,
+    "deepseek-v3-2-exp": 1,
 
     "deepseek-chat-8k": 0.5,
     "deepseek-chat-64k": 5,
@@ -1079,6 +1093,9 @@ MODEL_RATIO = {
 
     "claude-sonnet-4-20250514": 1.5,
     "claude-sonnet-4-20250514-thinking": 1.5,
+    "claude-sonnet-4-5-20250929": 1.5,
+    "claude-sonnet-4-5-20250929-thinking": 1.5,
+
     "claude-opus-4-20250514": 7.5,
     "claude-opus-4-20250514-thinking": 7.5,
     "claude-opus-4.1": 7.5,
@@ -1132,6 +1149,8 @@ MODEL_RATIO = {
 
     "gemini-2.5-flash-preview-04-17": 0.075,
 
+    "gemini-2.5-flash-preview-09-2025": 0.075,
+
     "gemini-2.0-pro": 0.625,
     "gemini-2.0-pro-exp": 0.625,
     "gemini-2.0-pro-exp-02-05": 0.625,
@@ -1334,6 +1353,9 @@ COMPLETION_RATIO = {
     "moonshot-v1-32k-vision-preview": 4,
     "moonshot-v1-128k-vision-preview": 3,
 
+    "longcat-flash-chat": 3,
+    "longcat-flash-thinking": 5,
+
     "grok-2": 5,
     "grok-2-1212": 5,
     "grok-2-vision-1212": 5,
@@ -1412,6 +1434,9 @@ COMPLETION_RATIO = {
 
     "claude-sonnet-4-20250514": 5,
     "claude-sonnet-4-20250514-thinking": 5,
+    "claude-sonnet-4-5-20250929": 5,
+    "claude-sonnet-4-5-20250929-thinking": 5,
+
     "claude-opus-4-20250514": 5,
     "claude-opus-4-20250514-thinking": 5,
     "claude-opus-4.1": 5,
@@ -1512,6 +1537,7 @@ COMPLETION_RATIO = {
     "gemini-2.5-flash-preview-05-20-thinking": 23,
     "gemini-2.5-flash-preview-05-20": 8.4,
     "gemini-2.5-flash-preview-05-20-nothinking": 8.4,
+    "gemini-2.5-flash-preview-09-2025": 8.4,
 
     "hunyuan-a52b-instruct": 5,
     "qwen2.5-coder-32b-instruct": 3,
@@ -1587,6 +1613,7 @@ COMPLETION_RATIO = {
 
     "qwen3-coder-plus": 4,
     "qwen3-coder-plus-2025-07-22": 4,
+    "qwen3-coder-plus-2025-09-23": 4,
 
     # 豆包
     "seed-x-ppo-7b": 1,
@@ -1677,8 +1704,10 @@ COMPLETION_RATIO = {
     "deepseek-v3-1-250821": 3,
     "deepseek-v3-1-think": 3,
 
-    "deepseek-v3-1-terminus": 3,
-    "deepseek-v3.1-terminus": 3,
+    "deepseek-v3-1-terminus": 1.5,
+    "deepseek-v3.1-terminus": 1.5,
+    "deepseek-v3.2-exp": 1.5,
+    "deepseek-v3-2-exp": 1.5,
 
     'deepseek-r1': 4,
     "deepseek-r1-160k": 5,
@@ -1724,6 +1753,7 @@ COMPLETION_RATIO = {
     "glm-4.5": 4,
     "glm-4.5-x": 4,
     "glm-4.5v": 3,
+    "glm-4.6": 4,
 
     "step-1-flash": 5,
     "step-1-8k": 5,
