@@ -127,7 +127,9 @@ class CompletionRequest(BaseModel):
     # Oneapi https://github.com/QuantumNous/new-api/blob/main/dto/openai_request.go
     extra_body: Optional[Any] = None
     enable_thinking: Optional[bool] = None  # ali
+
     thinking: Optional[dict] = None  # doubao "type": "disabled" "enabled" "auto"
+    thinking_budget: Optional[int] = None  # 思考预算
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -174,16 +176,17 @@ class CompletionRequest(BaseModel):
         return ""
 
     @cached_property
-    def last_urls(self):  # file_url 多轮对话需要  sum(request.last_urls.values(), [])
+    def last_urls(self):  # file_url 多轮对话需要  sum(request.last_urls.values(), []) # todo 位置信息
         """最新一轮的 user url 列表"""
         content_types = {
             "image_url",
 
-            "file", "file_url",
-
             "audio_url", "input_audio",
 
             "video_url",
+
+            "file_url", "file",
+
         }
         for i, message in enumerate(self.messages[::-1], 1):
             data = {}
@@ -201,7 +204,10 @@ class CompletionRequest(BaseModel):
                                     url = _url.get("url") or _url.get("data")
                                 url and data.setdefault(content_type, []).append(url)
 
-            if data: return data
+            if data:
+                data["audio_url"] = data.get("audio_url", []) + data.get("input_audio", [])
+                data["file_url"] = data.get("file_url", []) + data.get("file", [])
+                return data
         return {}
 
     # def create_message(self, text: str, content_type: Optional[str] = None):
