@@ -27,6 +27,7 @@ exc_set = {
 
     "supported format",
     "format unsupported",
+    "UnsupportedImageFormat",
 
     "invalid image",
     "Image Decode Error",
@@ -36,6 +37,8 @@ exc_set = {
     "cannot identify",
     "could not generate",
 
+    "Image size format should be like",
+
     # 大小/分辨率
     "Image resolution exceeds maximum",
     "Image dimensions out of range",
